@@ -765,7 +765,8 @@ def get_platform():
        solaris-2.6-sun4u
 
     Windows will return one of:
-       win-amd64 (64bit Windows on AMD64 (aka x86_64, Intel64, EM64T, etc)
+       win-amd64 (64-bit Windows on AMD64 (aka x86_64, Intel64, EM64T, etc)
+       win-arm64 (64-bit Windows on ARM64 (aka AArch64)
        win32 (all others - specifically, sys.platform is returned)
 
     For other non-POSIX platforms, currently just returns 'sys.platform'.
@@ -815,7 +816,7 @@ def get_platform():
     elif osname[:3] == "aix":
         from _aix_support import aix_platform
         return aix_platform()
-    elif osname[:6] == "cygwin" or osname[:4] == "msys":
+    elif sys.platform == "cygwin":
         # https://github.com/msys2/MSYS2-packages/issues/5143
         # Various build tools use the platform to derive the wheel tag
         # and the wheel tag needs to be stable for a specific platform
